import { TickFormatter } from "./tick_formatter";
export declare class LogTickFormatter extends TickFormatter {
    initialize(attrs: any, options: any): void;
    doFormat(ticks: any, axis: any): any;
}
