export declare class View {
    static getters(specs: any): any[];
    constructor(options?: {});
    initialize(options: any): void;
    remove(): any;
    toString(): string;
    connect_signals(): void;
    disconnect_signals(): void;
}
