import { ContinuousTicker } from "./continuous_ticker";
export declare class SingleIntervalTicker extends ContinuousTicker {
    get_interval(data_low: any, data_high: any, n_desired_ticks: any): any;
}
