import { HasProps } from "./has_props";
import * as hittest from "./hittest";
export declare class Selector extends HasProps {
    update(indices: any, final: any, append: any, silent?: boolean): any[] | undefined;
    clear(): hittest.HitTestResult;
}
