export declare var ProjectionUtils: {
    new (): {
        geographic_to_meters(xLon: any, yLat: any): any;
        meters_to_geographic(mx: any, my: any): any;
        geographic_extent_to_meters(extent: any): any[];
        meters_extent_to_geographic(extent: any): any[];
    };
};
