export declare type AngleUnits = "deg" | "rad";
export declare const AngleUnits: AngleUnits[];
export declare type Dimension = "width" | "height";
export declare const Dimension: Dimension[];
export declare type Dimensions = "width" | "height" | "both";
export declare const Dimensions: Dimensions[];
export declare type Direction = "clock" | "anticlock";
export declare const Direction: Direction[];
export declare type FontStyle = "normal" | "italic" | "bold";
export declare const FontStyle: FontStyle[];
export declare type LatLon = "lat" | "lon";
export declare const LatLon: LatLon[];
export declare type LineCap = "butt" | "round" | "square";
export declare const LineCap: LineCap[];
export declare type LineJoin = "miter" | "round" | "bevel";
export declare const LineJoin: LineJoin[];
export declare type Location = "above" | "below" | "left" | "right";
export declare const Location: Location[];
export declare type LegendLocation = "top_left" | "top_center" | "top_right" | "center_left" | "center" | "center_right" | "bottom_left" | "bottom_center" | "bottom_right";
export declare const LegendLocation: LegendLocation[];
export declare type Orientation = "vertical" | "horizontal";
export declare const Orientation: Orientation[];
export declare type OutputBackend = "canvas" | "svg" | "webgl";
export declare const OutputBackend: OutputBackend[];
export declare type RenderLevel = "image" | "underlay" | "glyph" | "annotation" | "overlay";
export declare const RenderLevel: RenderLevel[];
export declare type RenderMode = "canvas" | "css";
export declare const RenderMode: RenderMode[];
export declare type Side = "left" | "right";
export declare const Side: Side[];
export declare type SpatialUnits = "screen" | "data";
export declare const SpatialUnits: SpatialUnits[];
export declare type StartEnd = "start" | "end";
export declare const StartEnd: StartEnd[];
export declare type VerticalAlign = "top" | "middle" | "bottom";
export declare const VerticalAlign: VerticalAlign[];
export declare type TextAlign = "left" | "right" | "center";
export declare const TextAlign: TextAlign[];
export declare type TextBaseline = "top" | "middle" | "bottom" | "alphabetic" | "hanging" | "ideographic";
export declare const TextBaseline: TextBaseline[];
export declare type DistributionTypes = "uniform" | "normal";
export declare const DistributionTypes: DistributionTypes[];
export declare type StepModes = "after" | "before" | "center";
export declare const StepModes: StepModes[];
export declare type SizingMode = "stretch_both" | "scale_width" | "scale_height" | "scale_both" | "fixed";
export declare const SizingMode: SizingMode[];
export declare type PaddingUnits = "percent" | "absolute";
export declare const PaddingUnits: PaddingUnits[];
