import { InputWidget, InputWidgetView } from "./input_widget";
export declare class TextInputView extends InputWidgetView {
    initialize(options: any): this;
    connect_signals(): any;
    render(): this;
    change_input(): any;
}
export declare class TextInput extends InputWidget {
}
