import { LayoutDOM, LayoutDOMView } from "../layouts/layout_dom";
export declare class WidgetView extends LayoutDOMView {
    render(): string | undefined;
}
export declare class Widget extends LayoutDOM {
}
