export declare const YlGn3: number[];
export declare const YlGn4: number[];
export declare const YlGn5: number[];
export declare const YlGn6: number[];
export declare const YlGn7: number[];
export declare const YlGn8: number[];
export declare const YlGn9: number[];
export declare const YlGnBu3: number[];
export declare const YlGnBu4: number[];
export declare const YlGnBu5: number[];
export declare const YlGnBu6: number[];
export declare const YlGnBu7: number[];
export declare const YlGnBu8: number[];
export declare const YlGnBu9: number[];
export declare const GnBu3: number[];
export declare const GnBu4: number[];
export declare const GnBu5: number[];
export declare const GnBu6: number[];
export declare const GnBu7: number[];
export declare const GnBu8: number[];
export declare const GnBu9: number[];
export declare const BuGn3: number[];
export declare const BuGn4: number[];
export declare const BuGn5: number[];
export declare const BuGn6: number[];
export declare const BuGn7: number[];
export declare const BuGn8: number[];
export declare const BuGn9: number[];
export declare const PuBuGn3: number[];
export declare const PuBuGn4: number[];
export declare const PuBuGn5: number[];
export declare const PuBuGn6: number[];
export declare const PuBuGn7: number[];
export declare const PuBuGn8: number[];
export declare const PuBuGn9: number[];
export declare const PuBu3: number[];
export declare const PuBu4: number[];
export declare const PuBu5: number[];
export declare const PuBu6: number[];
export declare const PuBu7: number[];
export declare const PuBu8: number[];
export declare const PuBu9: number[];
export declare const BuPu3: number[];
export declare const BuPu4: number[];
export declare const BuPu5: number[];
export declare const BuPu6: number[];
export declare const BuPu7: number[];
export declare const BuPu8: number[];
export declare const BuPu9: number[];
export declare const RdPu3: number[];
export declare const RdPu4: number[];
export declare const RdPu5: number[];
export declare const RdPu6: number[];
export declare const RdPu7: number[];
export declare const RdPu8: number[];
export declare const RdPu9: number[];
export declare const PuRd3: number[];
export declare const PuRd4: number[];
export declare const PuRd5: number[];
export declare const PuRd6: number[];
export declare const PuRd7: number[];
export declare const PuRd8: number[];
export declare const PuRd9: number[];
export declare const OrRd3: number[];
export declare const OrRd4: number[];
export declare const OrRd5: number[];
export declare const OrRd6: number[];
export declare const OrRd7: number[];
export declare const OrRd8: number[];
export declare const OrRd9: number[];
export declare const YlOrRd3: number[];
export declare const YlOrRd4: number[];
export declare const YlOrRd5: number[];
export declare const YlOrRd6: number[];
export declare const YlOrRd7: number[];
export declare const YlOrRd8: number[];
export declare const YlOrRd9: number[];
export declare const YlOrBr3: number[];
export declare const YlOrBr4: number[];
export declare const YlOrBr5: number[];
export declare const YlOrBr6: number[];
export declare const YlOrBr7: number[];
export declare const YlOrBr8: number[];
export declare const YlOrBr9: number[];
export declare const Purples3: number[];
export declare const Purples4: number[];
export declare const Purples5: number[];
export declare const Purples6: number[];
export declare const Purples7: number[];
export declare const Purples8: number[];
export declare const Purples9: number[];
export declare const Blues3: number[];
export declare const Blues4: number[];
export declare const Blues5: number[];
export declare const Blues6: number[];
export declare const Blues7: number[];
export declare const Blues8: number[];
export declare const Blues9: number[];
export declare const Greens3: number[];
export declare const Greens4: number[];
export declare const Greens5: number[];
export declare const Greens6: number[];
export declare const Greens7: number[];
export declare const Greens8: number[];
export declare const Greens9: number[];
export declare const Oranges3: number[];
export declare const Oranges4: number[];
export declare const Oranges5: number[];
export declare const Oranges6: number[];
export declare const Oranges7: number[];
export declare const Oranges8: number[];
export declare const Oranges9: number[];
export declare const Reds3: number[];
export declare const Reds4: number[];
export declare const Reds5: number[];
export declare const Reds6: number[];
export declare const Reds7: number[];
export declare const Reds8: number[];
export declare const Reds9: number[];
export declare const Greys3: number[];
export declare const Greys4: number[];
export declare const Greys5: number[];
export declare const Greys6: number[];
export declare const Greys7: number[];
export declare const Greys8: number[];
export declare const Greys9: number[];
export declare const Greys10: number[];
export declare const Greys11: number[];
export declare const Greys256: number[];
export declare const PuOr3: number[];
export declare const PuOr4: number[];
export declare const PuOr5: number[];
export declare const PuOr6: number[];
export declare const PuOr7: number[];
export declare const PuOr8: number[];
export declare const PuOr9: number[];
export declare const PuOr10: number[];
export declare const PuOr11: number[];
export declare const BrBG3: number[];
export declare const BrBG4: number[];
export declare const BrBG5: number[];
export declare const BrBG6: number[];
export declare const BrBG7: number[];
export declare const BrBG8: number[];
export declare const BrBG9: number[];
export declare const BrBG10: number[];
export declare const BrBG11: number[];
export declare const PRGn3: number[];
export declare const PRGn4: number[];
export declare const PRGn5: number[];
export declare const PRGn6: number[];
export declare const PRGn7: number[];
export declare const PRGn8: number[];
export declare const PRGn9: number[];
export declare const PRGn10: number[];
export declare const PRGn11: number[];
export declare const PiYG3: number[];
export declare const PiYG4: number[];
export declare const PiYG5: number[];
export declare const PiYG6: number[];
export declare const PiYG7: number[];
export declare const PiYG8: number[];
export declare const PiYG9: number[];
export declare const PiYG10: number[];
export declare const PiYG11: number[];
export declare const RdBu3: number[];
export declare const RdBu4: number[];
export declare const RdBu5: number[];
export declare const RdBu6: number[];
export declare const RdBu7: number[];
export declare const RdBu8: number[];
export declare const RdBu9: number[];
export declare const RdBu10: number[];
export declare const RdBu11: number[];
export declare const RdGy3: number[];
export declare const RdGy4: number[];
export declare const RdGy5: number[];
export declare const RdGy6: number[];
export declare const RdGy7: number[];
export declare const RdGy8: number[];
export declare const RdGy9: number[];
export declare const RdGy10: number[];
export declare const RdGy11: number[];
export declare const RdYlBu3: number[];
export declare const RdYlBu4: number[];
export declare const RdYlBu5: number[];
export declare const RdYlBu6: number[];
export declare const RdYlBu7: number[];
export declare const RdYlBu8: number[];
export declare const RdYlBu9: number[];
export declare const RdYlBu10: number[];
export declare const RdYlBu11: number[];
export declare const Spectral3: number[];
export declare const Spectral4: number[];
export declare const Spectral5: number[];
export declare const Spectral6: number[];
export declare const Spectral7: number[];
export declare const Spectral8: number[];
export declare const Spectral9: number[];
export declare const Spectral10: number[];
export declare const Spectral11: number[];
export declare const RdYlGn3: number[];
export declare const RdYlGn4: number[];
export declare const RdYlGn5: number[];
export declare const RdYlGn6: number[];
export declare const RdYlGn7: number[];
export declare const RdYlGn8: number[];
export declare const RdYlGn9: number[];
export declare const RdYlGn10: number[];
export declare const RdYlGn11: number[];
export declare const Inferno3: number[];
export declare const Inferno4: number[];
export declare const Inferno5: number[];
export declare const Inferno6: number[];
export declare const Inferno7: number[];
export declare const Inferno8: number[];
export declare const Inferno9: number[];
export declare const Inferno10: number[];
export declare const Inferno11: number[];
export declare const Inferno256: number[];
export declare const Magma3: number[];
export declare const Magma4: number[];
export declare const Magma5: number[];
export declare const Magma6: number[];
export declare const Magma7: number[];
export declare const Magma8: number[];
export declare const Magma9: number[];
export declare const Magma10: number[];
export declare const Magma11: number[];
export declare const Magma256: number[];
export declare const Plasma3: number[];
export declare const Plasma4: number[];
export declare const Plasma5: number[];
export declare const Plasma6: number[];
export declare const Plasma7: number[];
export declare const Plasma8: number[];
export declare const Plasma9: number[];
export declare const Plasma10: number[];
export declare const Plasma11: number[];
export declare const Plasma256: number[];
export declare const Viridis3: number[];
export declare const Viridis4: number[];
export declare const Viridis5: number[];
export declare const Viridis6: number[];
export declare const Viridis7: number[];
export declare const Viridis8: number[];
export declare const Viridis9: number[];
export declare const Viridis10: number[];
export declare const Viridis11: number[];
export declare const Viridis256: number[];
export declare const Accent3: number[];
export declare const Accent4: number[];
export declare const Accent5: number[];
export declare const Accent6: number[];
export declare const Accent7: number[];
export declare const Accent8: number[];
export declare const Dark2_3: number[];
export declare const Dark2_4: number[];
export declare const Dark2_5: number[];
export declare const Dark2_6: number[];
export declare const Dark2_7: number[];
export declare const Dark2_8: number[];
export declare const Paired3: number[];
export declare const Paired4: number[];
export declare const Paired5: number[];
export declare const Paired6: number[];
export declare const Paired7: number[];
export declare const Paired8: number[];
export declare const Paired9: number[];
export declare const Paired10: number[];
export declare const Paired11: number[];
export declare const Paired12: number[];
export declare const Pastel1_3: number[];
export declare const Pastel1_4: number[];
export declare const Pastel1_5: number[];
export declare const Pastel1_6: number[];
export declare const Pastel1_7: number[];
export declare const Pastel1_8: number[];
export declare const Pastel1_9: number[];
export declare const Pastel2_3: number[];
export declare const Pastel2_4: number[];
export declare const Pastel2_5: number[];
export declare const Pastel2_6: number[];
export declare const Pastel2_7: number[];
export declare const Pastel2_8: number[];
export declare const Set1_3: number[];
export declare const Set1_4: number[];
export declare const Set1_5: number[];
export declare const Set1_6: number[];
export declare const Set1_7: number[];
export declare const Set1_8: number[];
export declare const Set1_9: number[];
export declare const Set2_3: number[];
export declare const Set2_4: number[];
export declare const Set2_5: number[];
export declare const Set2_6: number[];
export declare const Set2_7: number[];
export declare const Set2_8: number[];
export declare const Set3_3: number[];
export declare const Set3_4: number[];
export declare const Set3_5: number[];
export declare const Set3_6: number[];
export declare const Set3_7: number[];
export declare const Set3_8: number[];
export declare const Set3_9: number[];
export declare const Set3_10: number[];
export declare const Set3_11: number[];
export declare const Set3_12: number[];
export declare const Category10_3: number[];
export declare const Category10_4: number[];
export declare const Category10_5: number[];
export declare const Category10_6: number[];
export declare const Category10_7: number[];
export declare const Category10_8: number[];
export declare const Category10_9: number[];
export declare const Category10_10: number[];
export declare const Category20_3: number[];
export declare const Category20_4: number[];
export declare const Category20_5: number[];
export declare const Category20_6: number[];
export declare const Category20_7: number[];
export declare const Category20_8: number[];
export declare const Category20_9: number[];
export declare const Category20_10: number[];
export declare const Category20_11: number[];
export declare const Category20_12: number[];
export declare const Category20_13: number[];
export declare const Category20_14: number[];
export declare const Category20_15: number[];
export declare const Category20_16: number[];
export declare const Category20_17: number[];
export declare const Category20_18: number[];
export declare const Category20_19: number[];
export declare const Category20_20: number[];
export declare const Category20b_3: number[];
export declare const Category20b_4: number[];
export declare const Category20b_5: number[];
export declare const Category20b_6: number[];
export declare const Category20b_7: number[];
export declare const Category20b_8: number[];
export declare const Category20b_9: number[];
export declare const Category20b_10: number[];
export declare const Category20b_11: number[];
export declare const Category20b_12: number[];
export declare const Category20b_13: number[];
export declare const Category20b_14: number[];
export declare const Category20b_15: number[];
export declare const Category20b_16: number[];
export declare const Category20b_17: number[];
export declare const Category20b_18: number[];
export declare const Category20b_19: number[];
export declare const Category20b_20: number[];
export declare const Category20c_3: number[];
export declare const Category20c_4: number[];
export declare const Category20c_5: number[];
export declare const Category20c_6: number[];
export declare const Category20c_7: number[];
export declare const Category20c_8: number[];
export declare const Category20c_9: number[];
export declare const Category20c_10: number[];
export declare const Category20c_11: number[];
export declare const Category20c_12: number[];
export declare const Category20c_13: number[];
export declare const Category20c_14: number[];
export declare const Category20c_15: number[];
export declare const Category20c_16: number[];
export declare const Category20c_17: number[];
export declare const Category20c_18: number[];
export declare const Category20c_19: number[];
export declare const Category20c_20: number[];
export declare const Colorblind3: number[];
export declare const Colorblind4: number[];
export declare const Colorblind5: number[];
export declare const Colorblind6: number[];
export declare const Colorblind7: number[];
export declare const Colorblind8: number[];
export declare const YlGn: {
    YlGn3: number[];
    YlGn4: number[];
    YlGn5: number[];
    YlGn6: number[];
    YlGn7: number[];
    YlGn8: number[];
    YlGn9: number[];
};
export declare const YlGnBu: {
    YlGnBu3: number[];
    YlGnBu4: number[];
    YlGnBu5: number[];
    YlGnBu6: number[];
    YlGnBu7: number[];
    YlGnBu8: number[];
    YlGnBu9: number[];
};
export declare const GnBu: {
    GnBu3: number[];
    GnBu4: number[];
    GnBu5: number[];
    GnBu6: number[];
    GnBu7: number[];
    GnBu8: number[];
    GnBu9: number[];
};
export declare const BuGn: {
    BuGn3: number[];
    BuGn4: number[];
    BuGn5: number[];
    BuGn6: number[];
    BuGn7: number[];
    BuGn8: number[];
    BuGn9: number[];
};
export declare const PuBuGn: {
    PuBuGn3: number[];
    PuBuGn4: number[];
    PuBuGn5: number[];
    PuBuGn6: number[];
    PuBuGn7: number[];
    PuBuGn8: number[];
    PuBuGn9: number[];
};
export declare const PuBu: {
    PuBu3: number[];
    PuBu4: number[];
    PuBu5: number[];
    PuBu6: number[];
    PuBu7: number[];
    PuBu8: number[];
    PuBu9: number[];
};
export declare const BuPu: {
    BuPu3: number[];
    BuPu4: number[];
    BuPu5: number[];
    BuPu6: number[];
    BuPu7: number[];
    BuPu8: number[];
    BuPu9: number[];
};
export declare const RdPu: {
    RdPu3: number[];
    RdPu4: number[];
    RdPu5: number[];
    RdPu6: number[];
    RdPu7: number[];
    RdPu8: number[];
    RdPu9: number[];
};
export declare const PuRd: {
    PuRd3: number[];
    PuRd4: number[];
    PuRd5: number[];
    PuRd6: number[];
    PuRd7: number[];
    PuRd8: number[];
    PuRd9: number[];
};
export declare const OrRd: {
    OrRd3: number[];
    OrRd4: number[];
    OrRd5: number[];
    OrRd6: number[];
    OrRd7: number[];
    OrRd8: number[];
    OrRd9: number[];
};
export declare const YlOrRd: {
    YlOrRd3: number[];
    YlOrRd4: number[];
    YlOrRd5: number[];
    YlOrRd6: number[];
    YlOrRd7: number[];
    YlOrRd8: number[];
    YlOrRd9: number[];
};
export declare const YlOrBr: {
    YlOrBr3: number[];
    YlOrBr4: number[];
    YlOrBr5: number[];
    YlOrBr6: number[];
    YlOrBr7: number[];
    YlOrBr8: number[];
    YlOrBr9: number[];
};
export declare const Purples: {
    Purples3: number[];
    Purples4: number[];
    Purples5: number[];
    Purples6: number[];
    Purples7: number[];
    Purples8: number[];
    Purples9: number[];
};
export declare const Blues: {
    Blues3: number[];
    Blues4: number[];
    Blues5: number[];
    Blues6: number[];
    Blues7: number[];
    Blues8: number[];
    Blues9: number[];
};
export declare const Greens: {
    Greens3: number[];
    Greens4: number[];
    Greens5: number[];
    Greens6: number[];
    Greens7: number[];
    Greens8: number[];
    Greens9: number[];
};
export declare const Oranges: {
    Oranges3: number[];
    Oranges4: number[];
    Oranges5: number[];
    Oranges6: number[];
    Oranges7: number[];
    Oranges8: number[];
    Oranges9: number[];
};
export declare const Reds: {
    Reds3: number[];
    Reds4: number[];
    Reds5: number[];
    Reds6: number[];
    Reds7: number[];
    Reds8: number[];
    Reds9: number[];
};
export declare const Greys: {
    Greys3: number[];
    Greys4: number[];
    Greys5: number[];
    Greys6: number[];
    Greys7: number[];
    Greys8: number[];
    Greys9: number[];
    Greys10: number[];
    Greys11: number[];
    Greys256: number[];
};
export declare const PuOr: {
    PuOr3: number[];
    PuOr4: number[];
    PuOr5: number[];
    PuOr6: number[];
    PuOr7: number[];
    PuOr8: number[];
    PuOr9: number[];
    PuOr10: number[];
    PuOr11: number[];
};
export declare const BrBG: {
    BrBG3: number[];
    BrBG4: number[];
    BrBG5: number[];
    BrBG6: number[];
    BrBG7: number[];
    BrBG8: number[];
    BrBG9: number[];
    BrBG10: number[];
    BrBG11: number[];
};
export declare const PRGn: {
    PRGn3: number[];
    PRGn4: number[];
    PRGn5: number[];
    PRGn6: number[];
    PRGn7: number[];
    PRGn8: number[];
    PRGn9: number[];
    PRGn10: number[];
    PRGn11: number[];
};
export declare const PiYG: {
    PiYG3: number[];
    PiYG4: number[];
    PiYG5: number[];
    PiYG6: number[];
    PiYG7: number[];
    PiYG8: number[];
    PiYG9: number[];
    PiYG10: number[];
    PiYG11: number[];
};
export declare const RdBu: {
    RdBu3: number[];
    RdBu4: number[];
    RdBu5: number[];
    RdBu6: number[];
    RdBu7: number[];
    RdBu8: number[];
    RdBu9: number[];
    RdBu10: number[];
    RdBu11: number[];
};
export declare const RdGy: {
    RdGy3: number[];
    RdGy4: number[];
    RdGy5: number[];
    RdGy6: number[];
    RdGy7: number[];
    RdGy8: number[];
    RdGy9: number[];
    RdGy10: number[];
    RdGy11: number[];
};
export declare const RdYlBu: {
    RdYlBu3: number[];
    RdYlBu4: number[];
    RdYlBu5: number[];
    RdYlBu6: number[];
    RdYlBu7: number[];
    RdYlBu8: number[];
    RdYlBu9: number[];
    RdYlBu10: number[];
    RdYlBu11: number[];
};
export declare const Spectral: {
    Spectral3: number[];
    Spectral4: number[];
    Spectral5: number[];
    Spectral6: number[];
    Spectral7: number[];
    Spectral8: number[];
    Spectral9: number[];
    Spectral10: number[];
    Spectral11: number[];
};
export declare const RdYlGn: {
    RdYlGn3: number[];
    RdYlGn4: number[];
    RdYlGn5: number[];
    RdYlGn6: number[];
    RdYlGn7: number[];
    RdYlGn8: number[];
    RdYlGn9: number[];
    RdYlGn10: number[];
    RdYlGn11: number[];
};
export declare const Inferno: {
    Inferno3: number[];
    Inferno4: number[];
    Inferno5: number[];
    Inferno6: number[];
    Inferno7: number[];
    Inferno8: number[];
    Inferno9: number[];
    Inferno10: number[];
    Inferno11: number[];
    Inferno256: number[];
};
export declare const Magma: {
    Magma3: number[];
    Magma4: number[];
    Magma5: number[];
    Magma6: number[];
    Magma7: number[];
    Magma8: number[];
    Magma9: number[];
    Magma10: number[];
    Magma11: number[];
    Magma256: number[];
};
export declare const Plasma: {
    Plasma3: number[];
    Plasma4: number[];
    Plasma5: number[];
    Plasma6: number[];
    Plasma7: number[];
    Plasma8: number[];
    Plasma9: number[];
    Plasma10: number[];
    Plasma11: number[];
    Plasma256: number[];
};
export declare const Viridis: {
    Viridis3: number[];
    Viridis4: number[];
    Viridis5: number[];
    Viridis6: number[];
    Viridis7: number[];
    Viridis8: number[];
    Viridis9: number[];
    Viridis10: number[];
    Viridis11: number[];
    Viridis256: number[];
};
export declare const Accent: {
    Accent3: number[];
    Accent4: number[];
    Accent5: number[];
    Accent6: number[];
    Accent7: number[];
    Accent8: number[];
};
export declare const Dark2: {
    Dark2_3: number[];
    Dark2_4: number[];
    Dark2_5: number[];
    Dark2_6: number[];
    Dark2_7: number[];
    Dark2_8: number[];
};
export declare const Paired: {
    Paired3: number[];
    Paired4: number[];
    Paired5: number[];
    Paired6: number[];
    Paired7: number[];
    Paired8: number[];
    Paired9: number[];
    Paired10: number[];
    Paired11: number[];
    Paired12: number[];
};
export declare const Pastel1: {
    Pastel1_3: number[];
    Pastel1_4: number[];
    Pastel1_5: number[];
    Pastel1_6: number[];
    Pastel1_7: number[];
    Pastel1_8: number[];
    Pastel1_9: number[];
};
export declare const Pastel2: {
    Pastel2_3: number[];
    Pastel2_4: number[];
    Pastel2_5: number[];
    Pastel2_6: number[];
    Pastel2_7: number[];
    Pastel2_8: number[];
};
export declare const Set1: {
    Set1_3: number[];
    Set1_4: number[];
    Set1_5: number[];
    Set1_6: number[];
    Set1_7: number[];
    Set1_8: number[];
    Set1_9: number[];
};
export declare const Set2: {
    Set2_3: number[];
    Set2_4: number[];
    Set2_5: number[];
    Set2_6: number[];
    Set2_7: number[];
    Set2_8: number[];
};
export declare const Set3: {
    Set3_3: number[];
    Set3_4: number[];
    Set3_5: number[];
    Set3_6: number[];
    Set3_7: number[];
    Set3_8: number[];
    Set3_9: number[];
    Set3_10: number[];
    Set3_11: number[];
    Set3_12: number[];
};
export declare const Category10: {
    Category10_3: number[];
    Category10_4: number[];
    Category10_5: number[];
    Category10_6: number[];
    Category10_7: number[];
    Category10_8: number[];
    Category10_9: number[];
    Category10_10: number[];
};
export declare const Category20: {
    Category20_3: number[];
    Category20_4: number[];
    Category20_5: number[];
    Category20_6: number[];
    Category20_7: number[];
    Category20_8: number[];
    Category20_9: number[];
    Category20_10: number[];
    Category20_11: number[];
    Category20_12: number[];
    Category20_13: number[];
    Category20_14: number[];
    Category20_15: number[];
    Category20_16: number[];
    Category20_17: number[];
    Category20_18: number[];
    Category20_19: number[];
    Category20_20: number[];
};
export declare const Category20b: {
    Category20b_3: number[];
    Category20b_4: number[];
    Category20b_5: number[];
    Category20b_6: number[];
    Category20b_7: number[];
    Category20b_8: number[];
    Category20b_9: number[];
    Category20b_10: number[];
    Category20b_11: number[];
    Category20b_12: number[];
    Category20b_13: number[];
    Category20b_14: number[];
    Category20b_15: number[];
    Category20b_16: number[];
    Category20b_17: number[];
    Category20b_18: number[];
    Category20b_19: number[];
    Category20b_20: number[];
};
export declare const Category20c: {
    Category20c_3: number[];
    Category20c_4: number[];
    Category20c_5: number[];
    Category20c_6: number[];
    Category20c_7: number[];
    Category20c_8: number[];
    Category20c_9: number[];
    Category20c_10: number[];
    Category20c_11: number[];
    Category20c_12: number[];
    Category20c_13: number[];
    Category20c_14: number[];
    Category20c_15: number[];
    Category20c_16: number[];
    Category20c_17: number[];
    Category20c_18: number[];
    Category20c_19: number[];
    Category20c_20: number[];
};
export declare const Colorblind: {
    Colorblind3: number[];
    Colorblind4: number[];
    Colorblind5: number[];
    Colorblind6: number[];
    Colorblind7: number[];
    Colorblind8: number[];
};
