export declare const indianred = "#CD5C5C";
export declare const lightcoral = "#F08080";
export declare const salmon = "#FA8072";
export declare const darksalmon = "#E9967A";
export declare const lightsalmon = "#FFA07A";
export declare const crimson = "#DC143C";
export declare const red = "#FF0000";
export declare const firebrick = "#B22222";
export declare const darkred = "#8B0000";
export declare const pink = "#FFC0CB";
export declare const lightpink = "#FFB6C1";
export declare const hotpink = "#FF69B4";
export declare const deeppink = "#FF1493";
export declare const mediumvioletred = "#C71585";
export declare const palevioletred = "#DB7093";
export declare const coral = "#FF7F50";
export declare const tomato = "#FF6347";
export declare const orangered = "#FF4500";
export declare const darkorange = "#FF8C00";
export declare const orange = "#FFA500";
export declare const gold = "#FFD700";
export declare const yellow = "#FFFF00";
export declare const lightyellow = "#FFFFE0";
export declare const lemonchiffon = "#FFFACD";
export declare const lightgoldenrodyellow = "#FAFAD2";
export declare const papayawhip = "#FFEFD5";
export declare const moccasin = "#FFE4B5";
export declare const peachpuff = "#FFDAB9";
export declare const palegoldenrod = "#EEE8AA";
export declare const khaki = "#F0E68C";
export declare const darkkhaki = "#BDB76B";
export declare const lavender = "#E6E6FA";
export declare const thistle = "#D8BFD8";
export declare const plum = "#DDA0DD";
export declare const violet = "#EE82EE";
export declare const orchid = "#DA70D6";
export declare const fuchsia = "#FF00FF";
export declare const magenta = "#FF00FF";
export declare const mediumorchid = "#BA55D3";
export declare const mediumpurple = "#9370DB";
export declare const blueviolet = "#8A2BE2";
export declare const darkviolet = "#9400D3";
export declare const darkorchid = "#9932CC";
export declare const darkmagenta = "#8B008B";
export declare const purple = "#800080";
export declare const indigo = "#4B0082";
export declare const slateblue = "#6A5ACD";
export declare const darkslateblue = "#483D8B";
export declare const mediumslateblue = "#7B68EE";
export declare const greenyellow = "#ADFF2F";
export declare const chartreuse = "#7FFF00";
export declare const lawngreen = "#7CFC00";
export declare const lime = "#00FF00";
export declare const limegreen = "#32CD32";
export declare const palegreen = "#98FB98";
export declare const lightgreen = "#90EE90";
export declare const mediumspringgreen = "#00FA9A";
export declare const springgreen = "#00FF7F";
export declare const mediumseagreen = "#3CB371";
export declare const seagreen = "#2E8B57";
export declare const forestgreen = "#228B22";
export declare const green = "#008000";
export declare const darkgreen = "#006400";
export declare const yellowgreen = "#9ACD32";
export declare const olivedrab = "#6B8E23";
export declare const olive = "#808000";
export declare const darkolivegreen = "#556B2F";
export declare const mediumaquamarine = "#66CDAA";
export declare const darkseagreen = "#8FBC8F";
export declare const lightseagreen = "#20B2AA";
export declare const darkcyan = "#008B8B";
export declare const teal = "#008080";
export declare const aqua = "#00FFFF";
export declare const cyan = "#00FFFF";
export declare const lightcyan = "#E0FFFF";
export declare const paleturquoise = "#AFEEEE";
export declare const aquamarine = "#7FFFD4";
export declare const turquoise = "#40E0D0";
export declare const mediumturquoise = "#48D1CC";
export declare const darkturquoise = "#00CED1";
export declare const cadetblue = "#5F9EA0";
export declare const steelblue = "#4682B4";
export declare const lightsteelblue = "#B0C4DE";
export declare const powderblue = "#B0E0E6";
export declare const lightblue = "#ADD8E6";
export declare const skyblue = "#87CEEB";
export declare const lightskyblue = "#87CEFA";
export declare const deepskyblue = "#00BFFF";
export declare const dodgerblue = "#1E90FF";
export declare const cornflowerblue = "#6495ED";
export declare const royalblue = "#4169E1";
export declare const blue = "#0000FF";
export declare const mediumblue = "#0000CD";
export declare const darkblue = "#00008B";
export declare const navy = "#000080";
export declare const midnightblue = "#191970";
export declare const cornsilk = "#FFF8DC";
export declare const blanchedalmond = "#FFEBCD";
export declare const bisque = "#FFE4C4";
export declare const navajowhite = "#FFDEAD";
export declare const wheat = "#F5DEB3";
export declare const burlywood = "#DEB887";
export declare const tan = "#D2B48C";
export declare const rosybrown = "#BC8F8F";
export declare const sandybrown = "#F4A460";
export declare const goldenrod = "#DAA520";
export declare const darkgoldenrod = "#B8860B";
export declare const peru = "#CD853F";
export declare const chocolate = "#D2691E";
export declare const saddlebrown = "#8B4513";
export declare const sienna = "#A0522D";
export declare const brown = "#A52A2A";
export declare const maroon = "#800000";
export declare const white = "#FFFFFF";
export declare const snow = "#FFFAFA";
export declare const honeydew = "#F0FFF0";
export declare const mintcream = "#F5FFFA";
export declare const azure = "#F0FFFF";
export declare const aliceblue = "#F0F8FF";
export declare const ghostwhite = "#F8F8FF";
export declare const whitesmoke = "#F5F5F5";
export declare const seashell = "#FFF5EE";
export declare const beige = "#F5F5DC";
export declare const oldlace = "#FDF5E6";
export declare const floralwhite = "#FFFAF0";
export declare const ivory = "#FFFFF0";
export declare const antiquewhite = "#FAEBD7";
export declare const linen = "#FAF0E6";
export declare const lavenderblush = "#FFF0F5";
export declare const mistyrose = "#FFE4E1";
export declare const gainsboro = "#DCDCDC";
export declare const lightgray = "#D3D3D3";
export declare const lightgrey = "#D3D3D3";
export declare const silver = "#C0C0C0";
export declare const darkgray = "#A9A9A9";
export declare const darkgrey = "#A9A9A9";
export declare const gray = "#808080";
export declare const grey = "#808080";
export declare const dimgray = "#696969";
export declare const dimgrey = "#696969";
export declare const lightslategray = "#778899";
export declare const lightslategrey = "#778899";
export declare const slategray = "#708090";
export declare const slategrey = "#708090";
export declare const darkslategray = "#2F4F4F";
export declare const darkslategrey = "#2F4F4F";
export declare const black = "#000000";
