import { Scale } from "./scale";
export declare class LogScale extends Scale {
    compute(x: any): any;
    v_compute(xs: any): Float64Array;
    invert(xprime: any): number;
    v_invert(xprimes: any): Float64Array;
    _get_safe_factor(orig_start: any, orig_end: any): any[];
    _compute_state(): any[];
}
