export declare var BOKEH_ROOT: string;
export declare var add_document_static: (element: any, doc: any, use_for_title: any) => any;
export declare var add_document_standalone: (document: any, element: any, use_for_title?: boolean) => any;
export declare var inject_css: (url: any) => HTMLElement;
export declare var inject_raw_css: (css: any) => HTMLElement;
export declare var embed_items: (docs_json: any, render_items: any, app_path: any, absolute_url: any) => number;
