export declare function isBoolean(obj: any): obj is boolean;
export declare function isNumber(obj: any): obj is number;
export declare function isInteger(obj: any): obj is number;
export declare function isString(obj: any): obj is string;
export declare function isStrictNaN(obj: any): obj is number;
export declare function isFunction(obj: any): obj is Function;
export declare function isArray<T>(obj: any): obj is Array<T>;
export declare function isObject(obj: any): obj is Object;
