export declare var scale_highlow: (range: any, factor: any, center?: null) => number[];
export declare var get_info: (scales: any, [sxy0, sxy1]: [any, any]) => {};
export declare var scale_range: (frame: any, factor: any, h_axis?: boolean, v_axis?: boolean, center?: null) => {
    xrs: {};
    yrs: {};
    factor: any;
};
