import { LayoutProvider } from "./layout_provider";
export declare class StaticLayoutProvider extends LayoutProvider {
    get_node_coordinates(node_source: any): never[][];
    get_edge_coordinates(edge_source: any): never[][];
}
